//
//  tccCheck.m
//  tccKit
//
//  Created by Hal Mueller on 2018/09/19.
//  https://halmueller.wordpress.com
//  Copyright © 2018 Hal Mueller. All rights reserved.
//

#import "tccCheck.h"
#import <Carbon/Carbon.h>

@implementation tccCheck

- (NSString *)automationConsentForBundleIdentifier:(NSString *)bundleIdentifier promptIfNeeded:(BOOL)promptIfNeeded
{
    NSString *result;
    if (@available(macOS 10.14, *)) {
        AEAddressDesc addressDesc;
        
        // We need a C string here, not an NSString
        const char *bundleIdentifierCString = [bundleIdentifier cStringUsingEncoding:NSUTF8StringEncoding];
        OSErr createDescResult = AECreateDesc(typeApplicationBundleID, bundleIdentifierCString, strlen(bundleIdentifierCString), &addressDesc);
        OSStatus appleScriptPermission = AEDeterminePermissionToAutomateTarget(&addressDesc, typeWildCard, typeWildCard, promptIfNeeded);
        AEDisposeDesc(&addressDesc);
        
        switch (appleScriptPermission) {
            case errAEEventWouldRequireUserConsent:
                //NSLog(@"Automation consent not yet granted for %@, would require user consent.", bundleIdentifier);
                result =@"PrivacyConsentStateUnknown";
                break;
            case noErr:
                //NSLog(@"Automation permitted for %@.", bundleIdentifier);
                result = @"PrivacyConsentStateGranted";
                break;
            case errAEEventNotPermitted:
                //NSLog(@"Automation of %@ not permitted.", bundleIdentifier);
                result = @"PrivacyConsentStateDenied";
                break;
            case procNotFound:
                //NSLog(@"%@ not running, automation consent unknown.", bundleIdentifier);
                result = @"PrivacyConsentStateUnknown";
                break;
            default:
                //NSLog(@"%s switch statement fell through: %@ %d", __PRETTY_FUNCTION__, bundleIdentifier, appleScriptPermission);
                result = @"PrivacyConsentStateUnknown";
        }
        return result;
    }
    else {
        return @"PrivacyConsentStateGranted";
    }
    
}

@end

